pub enum Link {
Internal(InternalData),
Anchor(AnchorData),
RedLink(RedLinkData),
MediaLink(MediaData),
External(ExternalData),
ExternalToInternal(ExternalToInteralData),
}Variants
Internal(InternalData)
Interal link to another page in the same wiki
Anchor(AnchorData)
Anchor to a specific section in the current page
Note: this only corresponds to anchors on the current page. For anchors in another page on
the same wiki, LinkType::Internal is used
RedLink(RedLinkData)
A special type of link that leads to an internal page that doesn’t exist yet
MediaLink(MediaData)
Link pointing to a media
External(ExternalData)
External link to a page at another website
ExternalToInternal(ExternalToInteralData)
External link to an interal page in the same wiki
Implementations