QiProfile

Enum QiProfile 

pub enum QiProfile {
    Classic,
    ClassicNoBoostLinks,
    WSumIncLinks,
    WSumIncLinksPV,
    PopularIncLinksPV,
    PopularIncLinks,
    EngineAutoselect,
}
Query independent profile which affects the ranking algorithm

Variants



Classic

Ranking based on the number of incoming links, some templates, page language and recency (templates / language / recency may not be activated on the wiki where the search is performed on)

Ranking based on some templates, page language and recency when activated on the wiki where the search is performed on

Weighted sum based on incoming links



WSumIncLinksPV

Weighted sum based on incoming links and weekly pageviews



PopularIncLinksPV

Ranking based primarily on page views

Ranking based primarily on incoming link counts



EngineAutoselect

Let the search engine decide on the best profile to use