pub struct SearchContinue {
pub query: String,
pub endpoint: Endpoint,
pub language: Language,
pub offset: usize,
}Expand description
Contains the necessary data for continuing a Search at a given offset. This data can be
extracted from a already existing search with Search::continue_data
Example
// This will continue the already completed search
let continue_data = search.continue_data()?;
let continued_search = Search::builder()
.query(continue_data.query)
.endpoint(continue_data.endpoint)
.langauge(continue_data.language)
.offset(continue_data.offset)
.search()?;Fields
query: StringSearch for page titles or content matching this value
endpoint: EndpointAPI endpoint of the MediaWiki site to perform the search on
language: LanguageIn what language to perform the search
offset: usizeOffset where the search will continue