pub struct SearchResult {
pub namespace: Namespace,
pub title: String,
pub pageid: usize,
pub language: Language,
pub endpoint: Endpoint,
pub size: Option<usize>,
pub wordcount: Option<usize>,
pub snippet: Option<String>,
pub timestamp: Option<String>,
}Expand description
A single search result containing additional optional properties if they were added in the search
Fields
namespace: NamespaceNamespace where the page belongs to
title: StringTitle of the page
pageid: usizePageId of the page
language: LanguageLanguage, the page is written in
endpoint: EndpointAPI endpoint of the MediaWiki site this page belongs to
size: Option<usize>Optional: Size in bytes of the page
wordcount: Option<usize>Optional: Word count of the page
snippet: Option<String>Optional: Snippet of the page, with query term highlighting markup
timestamp: Option<String>Optional: Timestamp of when the page was last edited
Implementations
Sourceimpl SearchResult
impl SearchResult
pub fn cleaned_snippet(&self) -> String