Module search Copy item path Source Info A Search metadata Search A finished search containing the found results and additional optional information regarding
the search SearchBuilder A SearchBuilder can be used to configure and perform a search SearchContinue Contains the necessary data for continuing a Search at a given offset. This data can be
extracted from a already existing search with Search::continue_data SearchInfo Contains general informations about the search SearchResult A single search result containing additional optional properties if they were added in the
search Namespace The 16 built-in namespaces (excluding two “virtual” namespaces) of MediaWiki Property A Page property QiProfile Query independent profile which affects the ranking algorithm SearchType The type of search SortOrder The sort order of returned search results SearchRequest A fully configured SearchBuilder that can be used to execute the search. This is a convenience type