pub enum QiProfile {
Classic,
ClassicNoBoostLinks,
WSumIncLinks,
WSumIncLinksPV,
PopularIncLinksPV,
PopularIncLinks,
EngineAutoselect,
}Expand description
Query independent profile which affects the ranking algorithm
Variants
Classic
Ranking based on the number of incoming links, some templates, page language and recency (templates / language / recency may not be activated on the wiki where the search is performed on)
ClassicNoBoostLinks
Ranking based on some templates, page language and recency when activated on the wiki where the search is performed on
WSumIncLinks
Weighted sum based on incoming links
WSumIncLinksPV
Weighted sum based on incoming links and weekly pageviews
PopularIncLinksPV
Ranking based primarily on page views
PopularIncLinks
Ranking based primarily on incoming link counts
EngineAutoselect
Let the search engine decide on the best profile to use